@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: SQLite setup/teardown for tests
 
-our $VERSION = '0.0405';
+our $VERSION = '0.0406';
 
 use DBI;
 use File::Copy;
@@ -91,7 +91,7 @@ sub _build__database {
 
             $sql .= $line;
 
-            if ( $line =~ /;\s*(?:--.*)?$/ ) {
+            if ( $line =~ /;/ ) {
                 $dbh->do($sql)
                     or die 'Error executing SQL for ' . $self->schema . ': ' . $dbh->errstr;
 
@@ -130,7 +130,7 @@ Test::SQLite - SQLite setup/teardown for tests
 
 =head1 VERSION
 
-version 0.0405
+version 0.0406
 
 =head1 SYNOPSIS
 
@@ -190,8 +190,7 @@ constructor.
 
 The SQL schema with which to create a test database.
 
-* The SQL parsing done by this module does not handle triggers or
-c-style comments.
+* The SQL parsing done by this module does not handle triggers.
 
 =head2 has_schema
 
